@@ -1,6 +1,6 @@
 package Apache::Session::Browseable;
 
-our $VERSION = '1.3.5';
+our $VERSION = '1.3.18';
 
 print STDERR "Use a sub module of Apache::Session::Browseable such as Apache::Session::Browseable::File";
 
@@ -33,6 +33,9 @@ chosen module documentation carefully to set the indexes.
 
 =item L<Apache::Session::Browseable::PgJSON>: uses "json/jsonb" field
 
+=item L<Apache::Session::Browseable::Patroni>: uses "json/jsonb" field and
+manage connection using Patroni API to find master node of PostgreSQL cluster
+
 =back
 
 =head3 MySQL or MariaDB
@@ -63,6 +66,8 @@ chosen module documentation carefully to set the indexes.
 
 =item L<Apache::Session::Browseable::Redis>
 
+=item L<Apache::Session::Browseable::Cassandra>
+
 =back
 
 =head1 SEE ALSO
@@ -70,10 +75,6 @@ chosen module documentation carefully to set the indexes.
 L<Apache::Session>, L<http://lemonldap-ng.org>,
 L<https://lemonldap-ng.org/documentation/2.0/performances#performance_test>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
@@ -82,9 +83,15 @@ Copyright (C):
 
 =over
 
-=item 2009-2017 by Xavier Guimard
+=item 2009-2025 by Xavier Guimard
 
-=item 2013-2017 by Clément Oudot
+=item 2013-2025 by Clément Oudot
+
+=item 2019-2025 by Maxime Besson
+
+=item 2013-2025 by Worteks
+
+=item 2023-2025 by Linagora
 
 =back
 
