@@ -8,7 +8,7 @@ use Apache::Session::Browseable::Store::Postgres;
 use Apache::Session::Generate::SHA256;
 use Apache::Session::Serialize::Hstore;
 
-our $VERSION = '1.2.7';
+our $VERSION = '1.3.9';
 our @ISA     = qw(Apache::Session);
 
 sub populate {
@@ -36,7 +36,7 @@ sub searchOn {
 sub searchOnExpr {
     my ( $class, $args, $selectField, $value, @fields ) = @_;
     $selectField =~ s/'/''/g;
-    $value =~ s/\*/%/g;
+    $value       =~ s/\*/%/g;
     my $query =
       { query => "a_session -> '$selectField' like ?", values => [$value] };
     return $class->_query( $args, $query, @fields );
@@ -74,8 +74,14 @@ sub _query {
         my $self = eval "&${class}::populate();";
         my $sub  = $self->{unserialize};
         foreach my $s ( keys %$res ) {
-            my $tmp = &$sub( { serialized => $res->{$s}->{a_session} } );
-            $res->{$s} = $tmp;
+            eval {
+                my $tmp = &$sub( { serialized => $res->{$s}->{a_session} } );
+                $res->{$s} = $tmp;
+            };
+            if ($@) {
+                print STDERR "Error in session $s: $@\n";
+                delete $res->{$s};
+            }
         }
     }
     return $res;
@@ -104,8 +110,16 @@ sub deleteIfLowerThan {
     my $dbh        = $class->_classDbh($args);
     my $table_name = $args->{TableName}
       || $Apache::Session::Store::DBI::TableName;
-    my $sth = $dbh->do("DELETE FROM $table_name WHERE $query");
-    return 1;
+    my $rows = $dbh->do("DELETE FROM $table_name WHERE $query");
+    return 0 unless defined $rows;
+
+    if (wantarray) {
+        $rows = 0 if $rows == -1;
+        return ( 1, $rows );
+    }
+    else {
+        return 1;
+    }
 }
 
 sub get_key_from_all_sessions {
@@ -204,16 +218,23 @@ using "hstore" extension to be able to browse sessions.
 
 L<http://lemonldap-ng.org>, L<Apache::Session::Postgres>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-Copyright (C) 2009-2017 by Xavier Guimard
-              2013-2017 by Clément Oudot
+=over
+
+=item 2009-2025 by Xavier Guimard
+
+=item 2013-2025 by Clément Oudot
+
+=item 2019-2025 by Maxime Besson
+
+=item 2013-2025 by Worteks
+
+=item 2023-2025 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
